==> gr-mc4020-0.4.tar.gz: gr-mc4020-0.4/src/mc4020.py <==
# This file was created automatically by SWIG.
# Don't modify this file, modify the SWIG interface instead.
# This file is compatible with both classic and new-style classes.

import _mc4020

def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name) or (name == "thisown"):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


MCC_CH0_EN = _mc4020.MCC_CH0_EN
MCC_CH1_EN = _mc4020.MCC_CH1_EN
MCC_CH2_EN = _mc4020.MCC_CH2_EN
MCC_CH3_EN = _mc4020.MCC_CH3_EN
MCC_CH0_5V = _mc4020.MCC_CH0_5V
MCC_CH0_1V = _mc4020.MCC_CH0_1V
MCC_CH1_5V = _mc4020.MCC_CH1_5V
MCC_CH1_1V = _mc4020.MCC_CH1_1V
MCC_CH2_5V = _mc4020.MCC_CH2_5V
MCC_CH2_1V = _mc4020.MCC_CH2_1V
MCC_CH3_5V = _mc4020.MCC_CH3_5V
MCC_CH3_1V = _mc4020.MCC_CH3_1V
MCC_ASRC_MASK = _mc4020.MCC_ASRC_MASK
MCC_ASRC_BNC = _mc4020.MCC_ASRC_BNC
MCC_ASRC_CAL_AGND = _mc4020.MCC_ASRC_CAL_AGND
MCC_ASRC_CAL_0_625 = _mc4020.MCC_ASRC_CAL_0_625
MCC_ASRC_CAL_4_375 = _mc4020.MCC_ASRC_CAL_4_375
MCC_ASRC_CAL_HDR = _mc4020.MCC_ASRC_CAL_HDR
MCC_EXT_BNC_THRESH_ZERO = _mc4020.MCC_EXT_BNC_THRESH_ZERO
MCC_EXT_BNC_THRESH_2_5V = _mc4020.MCC_EXT_BNC_THRESH_2_5V
MCC_CLK_MASK = _mc4020.MCC_CLK_MASK
MCC_CLK_INTERNAL = _mc4020.MCC_CLK_INTERNAL
MCC_CLK_EXT_BNC = _mc4020.MCC_CLK_EXT_BNC
MCC_CLK_AD_START_TRIG_IN = _mc4020.MCC_CLK_AD_START_TRIG_IN
MCC_ALL_1V = _mc4020.MCC_ALL_1V
MCC_ALL_5V = _mc4020.MCC_ALL_5V
class mc4020_source_sptr(_object):
    """Proxy of C++ mc4020_source_sptr class"""
    __swig_setmethods__ = {}
    __setattr__ = lambda self, name, value: _swig_setattr(self, mc4020_source_sptr, name, value)
    __swig_getmethods__ = {}
    __getattr__ = lambda self, name: _swig_getattr(self, mc4020_source_sptr, name)
    def __repr__(self):
        return "<%s.%s; proxy of C++ boost::shared_ptr<mc4020_source > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    def __init__(self, *args):
        """
        __init__(self) -> mc4020_source_sptr
        __init__(self,  p) -> mc4020_source_sptr
        """
        _swig_setattr(self, mc4020_source_sptr, 'this', _mc4020.new_mc4020_source_sptr(*args))
        _swig_setattr(self, mc4020_source_sptr, 'thisown', 1)
    def __deref__(*args): 
        """__deref__(self)"""
        return _mc4020.mc4020_source_sptr___deref__(*args)

    def name(*args): 
        """name(self) -> string"""
        return _mc4020.mc4020_source_sptr_name(*args)

    def input_signature(*args): 
        """input_signature(self) -> gr_io_signature_sptr"""
        return _mc4020.mc4020_source_sptr_input_signature(*args)

    def output_signature(*args): 
        """output_signature(self) -> gr_io_signature_sptr"""
        return _mc4020.mc4020_source_sptr_output_signature(*args)

    def unique_id(*args): 
        """unique_id(self) -> long"""
        return _mc4020.mc4020_source_sptr_unique_id(*args)

    def output_multiple(*args): 
        """output_multiple(self) -> int"""
        return _mc4020.mc4020_source_sptr_output_multiple(*args)

    def relative_rate(*args): 
        """relative_rate(self) -> double"""
        return _mc4020.mc4020_source_sptr_relative_rate(*args)

    def check_topology(*args): 
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _mc4020.mc4020_source_sptr_check_topology(*args)

    def detail(*args): 
        """detail(self) -> gr_block_detail_sptr"""
        return _mc4020.mc4020_source_sptr_detail(*args)

    def set_detail(*args): 
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _mc4020.mc4020_source_sptr_set_detail(*args)

    def __del__(self, destroy=_mc4020.delete_mc4020_source_sptr):
        """__del__(self)"""
        try:
            if self.thisown: destroy(self)
        except: pass


class mc4020_source_sptrPtr(mc4020_source_sptr):
    def __init__(self, this):
        _swig_setattr(self, mc4020_source_sptr, 'this', this)
        if not hasattr(self,"thisown"): _swig_setattr(self, mc4020_source_sptr, 'thisown', 0)
        _swig_setattr(self, mc4020_source_sptr,self.__class__,mc4020_source_sptr)
_mc4020.mc4020_source_sptr_swigregister(mc4020_source_sptrPtr)


def mc4020_source_block(*args):
    """mc4020_source_block(mc4020_source_sptr r) -> gr_block_sptr"""
    return _mc4020.mc4020_source_block(*args)
mc4020_source_sptr.block = lambda self: mc4020_source_block (self)
mc4020_source_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


def source(*args):
    """
    source(double sampling_freq=20e6, unsigned long config_bitmask=0x00000001|(0x00000010|0x00000020|0x00000040|0x00000080), 
        string dev="/dev/mc4020_0") -> mc4020_source_sptr
    source(double sampling_freq=20e6, unsigned long config_bitmask=0x00000001|(0x00000010|0x00000020|0x00000040|0x00000080)) -> mc4020_source_sptr
    source(double sampling_freq=20e6) -> mc4020_source_sptr
    source() -> mc4020_source_sptr
    """
    return _mc4020.source(*args)

==> gr-mc4020-0.5.tar.gz: gr-mc4020-0.5/src/mc4020.py <==
# This file was created automatically by SWIG.
# Don't modify this file, modify the SWIG interface instead.

import _mc4020

def _swig_setattr_nondynamic(self,class_type,name,value,static=1):
    if (name == "this"):
        if isinstance(value, class_type):
            self.__dict__[name] = value.this
            if hasattr(value,"thisown"): self.__dict__["thisown"] = value.thisown
            del value.thisown
            return
    method = class_type.__swig_setmethods__.get(name,None)
    if method: return method(self,value)
    if (not static) or hasattr(self,name) or (name == "thisown"):
        self.__dict__[name] = value
    else:
        raise AttributeError("You cannot add attributes to %s" % self)

def _swig_setattr(self,class_type,name,value):
    return _swig_setattr_nondynamic(self,class_type,name,value,0)

def _swig_getattr(self,class_type,name):
    method = class_type.__swig_getmethods__.get(name,None)
    if method: return method(self)
    raise AttributeError,name

import types
try:
    _object = types.ObjectType
    _newclass = 1
except AttributeError:
    class _object : pass
    _newclass = 0
del types


def _swig_setattr_nondynamic_method(set):
    def set_attr(self,name,value):
        if hasattr(self,name) or (name in ("this", "thisown")):
            set(self,name,value)
        else:
            raise AttributeError("You cannot add attributes to %s" % self)
    return set_attr


MCC_CH0_EN = _mc4020.MCC_CH0_EN
MCC_CH1_EN = _mc4020.MCC_CH1_EN
MCC_CH2_EN = _mc4020.MCC_CH2_EN
MCC_CH3_EN = _mc4020.MCC_CH3_EN
MCC_CH0_5V = _mc4020.MCC_CH0_5V
MCC_CH0_1V = _mc4020.MCC_CH0_1V
MCC_CH1_5V = _mc4020.MCC_CH1_5V
MCC_CH1_1V = _mc4020.MCC_CH1_1V
MCC_CH2_5V = _mc4020.MCC_CH2_5V
MCC_CH2_1V = _mc4020.MCC_CH2_1V
MCC_CH3_5V = _mc4020.MCC_CH3_5V
MCC_CH3_1V = _mc4020.MCC_CH3_1V
MCC_ASRC_MASK = _mc4020.MCC_ASRC_MASK
MCC_ASRC_BNC = _mc4020.MCC_ASRC_BNC
MCC_ASRC_CAL_AGND = _mc4020.MCC_ASRC_CAL_AGND
MCC_ASRC_CAL_0_625 = _mc4020.MCC_ASRC_CAL_0_625
MCC_ASRC_CAL_4_375 = _mc4020.MCC_ASRC_CAL_4_375
MCC_ASRC_CAL_HDR = _mc4020.MCC_ASRC_CAL_HDR
MCC_EXT_BNC_THRESH_ZERO = _mc4020.MCC_EXT_BNC_THRESH_ZERO
MCC_EXT_BNC_THRESH_2_5V = _mc4020.MCC_EXT_BNC_THRESH_2_5V
MCC_CLK_MASK = _mc4020.MCC_CLK_MASK
MCC_CLK_INTERNAL = _mc4020.MCC_CLK_INTERNAL
MCC_CLK_EXT_BNC = _mc4020.MCC_CLK_EXT_BNC
MCC_CLK_AD_START_TRIG_IN = _mc4020.MCC_CLK_AD_START_TRIG_IN
MCC_ALL_1V = _mc4020.MCC_ALL_1V
MCC_ALL_5V = _mc4020.MCC_ALL_5V
class mc4020_source_sptr(object):
    """Proxy of C++ mc4020_source_sptr class"""
    def __repr__(self):
        return "<%s.%s; proxy of C++ boost::shared_ptr<mc4020_source > instance at %s>" % (self.__class__.__module__, self.__class__.__name__, self.this,)
    def __init__(self, *args):
        """
        __init__(self) -> mc4020_source_sptr
        __init__(self,  p) -> mc4020_source_sptr
        """
        newobj = _mc4020.new_mc4020_source_sptr(*args)
        self.this = newobj.this
        self.thisown = 1
        del newobj.thisown
    def __deref__(*args):
        """__deref__(self)"""
        return _mc4020.mc4020_source_sptr___deref__(*args)

    def name(*args):
        """name(self) -> string"""
        return _mc4020.mc4020_source_sptr_name(*args)

    def input_signature(*args):
        """input_signature(self) -> gr_io_signature_sptr"""
        return _mc4020.mc4020_source_sptr_input_signature(*args)

    def output_signature(*args):
        """output_signature(self) -> gr_io_signature_sptr"""
        return _mc4020.mc4020_source_sptr_output_signature(*args)

    def unique_id(*args):
        """unique_id(self) -> long"""
        return _mc4020.mc4020_source_sptr_unique_id(*args)

    def history(*args):
        """history(self) -> unsigned int"""
        return _mc4020.mc4020_source_sptr_history(*args)

    def output_multiple(*args):
        """output_multiple(self) -> int"""
        return _mc4020.mc4020_source_sptr_output_multiple(*args)

    def relative_rate(*args):
        """relative_rate(self) -> double"""
        return _mc4020.mc4020_source_sptr_relative_rate(*args)

    def check_topology(*args):
        """check_topology(self, int ninputs, int noutputs) -> bool"""
        return _mc4020.mc4020_source_sptr_check_topology(*args)

    def start(*args):
        """start(self) -> bool"""
        return _mc4020.mc4020_source_sptr_start(*args)

    def stop(*args):
        """stop(self) -> bool"""
        return _mc4020.mc4020_source_sptr_stop(*args)

    def detail(*args):
        """detail(self) -> gr_block_detail_sptr"""
        return _mc4020.mc4020_source_sptr_detail(*args)

    def set_detail(*args):
        """set_detail(self, gr_block_detail_sptr detail)"""
        return _mc4020.mc4020_source_sptr_set_detail(*args)

    def __del__(self, destroy=_mc4020.delete_mc4020_source_sptr):
        """__del__(self)"""
        try:
            if self.thisown: destroy(self)
        except: pass


class mc4020_source_sptrPtr(mc4020_source_sptr):
    def __init__(self, this):
        self.this = this
        if not hasattr(self,"thisown"): self.thisown = 0
        self.__class__ = mc4020_source_sptr
_mc4020.mc4020_source_sptr_swigregister(mc4020_source_sptrPtr)


def mc4020_source_block(*args):
    """mc4020_source_block(mc4020_source_sptr r) -> gr_block_sptr"""
    return _mc4020.mc4020_source_block(*args)
mc4020_source_sptr.block = lambda self: mc4020_source_block (self)
mc4020_source_sptr.__repr__ = lambda self: "<gr_block %s (%d)>" % (self.name(), self.unique_id ())


def source(*args):
    """
    source(double sampling_freq=20e6, unsigned long config_bitmask=0x00000001|(0x00000010|0x00000020|0x00000040|0x00000080), 
        string dev="/dev/mc4020_0") -> mc4020_source_sptr
    source(double sampling_freq=20e6, unsigned long config_bitmask=0x00000001|(0x00000010|0x00000020|0x00000040|0x00000080)) -> mc4020_source_sptr
    source(double sampling_freq=20e6) -> mc4020_source_sptr
    source() -> mc4020_source_sptr
    """
    return _mc4020.source(*args)
